# by DCL manual
#english
=begin
==NumRu::AdvancedDCL::Axis
==About this module
This is the module for drawing axes automatically.
===Position of Coordinate Axes
To use Axis, Axis::Lin, Axis::Log modules, the normalization transformation (in a Cartesian coordinate system) for transformation function number 1-4 must be set. (See ((<basics of this library>)) ) For example, assume that the following calls have been made.   
  Fig.viewport=[VXMIN,VXMAX,VYMIN,VYMAX]
  Fig.window=[UXMIN,UXMAX,UYMIN,UYMAX] 
  Fig.transnum=ITR

</blockquote>Then, Axis::Lin can set the coordinate axes in the following positions.   

For X axis;    
  '<tt>B</tt>'ottom - on a line connecting (<tt>UXMIN, UYMIN)</tt> and <tt> (UXMAX, UYMIN)</tt>
  '<tt>T</tt>'op - on a line connecting <tt>(UXMIN, UYMAX)</tt> and <tt>(UXMAX, UYMAX)</tt> 
  '<tt>U</tt>'ser - on a line connecting <tt>(UXMIN, UYUSER)</tt> and <tt>(UXMAX, UYUSER)</tt>

For Y axis;   
  '<tt>L</tt>'eft - on a line connecting <tt>(UXMIN, UYMIN)</tt> and <tt> (UXMIN, UYMAX)</tt>
  '<tt>R</tt>'ight - on a line connecting <tt>(UXMAX, UYMIN)</tt> and <tt> (UXMAX, UYMAX)</tt>
  '<tt>U</tt>'ser - on a line connecting <tt>(UXUSER, UYMIN)</tt> and <tt> (UXUSER, UYMAX)</tt>

The <tt>'B'</tt>, <tt>'T'</tt>, and <tt>'U'</tt> for the x axis, and the <tt>'L'</tt>, <tt>'R'</tt>, and <tt>'U'</tt> for the y axis, will be used as a parameter (<tt>CSIDE</tt>) for specifying the position to draw the components of the coordinate axes (see next section). <tt>UXUSER</tt> and <tt>UYUSER</tt> become effective when the internal variables <tt>'UXUSER'</tt> and <tt>'UYUSER'</tt> are set. (The initial values are undefined.) These positions for the coordinate axes can be shifted parallel in the Y direction using <tt>Axis::Lin.xsaxs</tt> in the Axis::Lin module, and shifted parallel in the X direction using <tt>Axis::Lin.ysaxs</tt>.

===Components and Attributes of the Axes
The coordinate axes drawn by Axis::Lin have the following components. (The names of the subroutines which draws the component are shown in parentheses.)   
(1)Line segment for the axes <tt>(Axis::Lin.xpaxs/ypaxs)</tt> 
(2)Tick Marks <tt>(Axis::Lin.xptmk/yptmk)</tt> 
(3)Label 
   * Specification by text <tt>(Axis::Lin.xplbl/yplbl)</tt> 
   * Specification by numerical values <tt>(Axis::Lin.xpnum/ypnum)</tt> 
(4)Title <tt>(Axis::Lin.xpttl/ypttl)</tt> 

The components have the following attributes. 
(1)Line segment for the axes   
     a. The line index of a line segment <ISLCT>
(2)Tick Marks 
     a. The length of a tick mark <ISLCT>
     b. The line index for the line of a tick mark <ISLCT>
(3)Label 
     a. The character height <ISLCT>
     b. The angle of rotation of the text <CSIDE>
     c. The centering option of the text <CSIDE>
     d. The line index for the lines of the text <ISLCT>
(4)Title 
     a. The character height <ISLCT>
     b. The angle of rotation of the text <CSIDE>
     c. The centering option of the text <Argument>
     d. The line index for the lines of the text <ISLCT>

The methods for specifying these attributes and the definitions of <ISLCT>, <CSIDE>, <Argument>will be given in the next section.

When the parameters for the coordinate axes are not set by '<tt>U</tt>'ser, the label and title will always be drawn on the outside of the window. When set by&nbsp; '<tt>U</tt>'ser, the label and title will be drawn on the side of the   
axes specified by the internal variable <tt>'IFLAG'</tt>.

===Specification of Attributes
Each subroutine in Axis::Lin have two arguments named <tt>ISLCT</tt> and <tt>CSIDE</tt>. These two and other arguments specify the attributes of each component.    
(1)ISLCT takes the value of 0, 1, or 2 Of the attributes introduced, those with <ISLCT> are set by inquiring the the internal variable specified by these arguments. The actual meanings of ISLCT=0,1,2 are    
    * ISLCT=0: draw graphics using the internal variables defined by user.  
    * ISLCT=1: draw graphics using the internal variables preset by this package. Used for drawing minor tick marks, labels, and title.   
    * ISLCT=2: draw graphics using the internal variables preset by this package. Used for drawing large tick marks, labels, and title.  

For example, the line index of the line for the axis has the internal variables <tt>'INDEXT0'</tt>, <tt>'INDEXT1'</tt>, and <tt>'INDEXT2'</tt>for<tt>ISLCT=0,1,2</tt>, respectively (with initial values of undefined, 1, and 3, respectively), and the attributed are set by inquiring these internal variables. Hereafter, this will be expressed as: &quot;The attributes of the line index will be set by inquiring the values specified by the internal variables <tt>'INDEXT</tt><i>i</i><tt>' </tt>(The initial values are undefined, 1, and 3).&quot; These internal variables can be inquired/changed using <tt>Axis::Lin.get</tt>, <tt>Axis::lin.set</tt>.
(2)CSIDE specifies the position to draw the component as well as to set the attributes that are dependent on the draw position. Of the attributes, those with <CSIDE> are set by inquiring the internal variables specified by this argument. For example, the angle of rotation of the X axis title has the internal variables <tt>'IROTCXB'</tt>, <tt>'IROTCXT'</tt>, and <tt>'IROTCXU' </tt>for&nbsp; <tt>CSIDE='B','T', and 'U'</tt>, respectively (with initial values of 0, 0, and 0, respectively), and the attributes are set by inquiring these internal variables. Hereafter, this will be expressed as: The attributes of the rotation angle of the&nbsp; X axis title will be set by inquiring the values specified by the internal variables <tt>irotcx(s)</tt>(The initial values are 0, 0, and 0.). Also, the angle of rotation of the Y axis title has the internal variables <tt>irotcyl</tt>, <tt>irotcyr</tt>, and <tt>irotcyu</tt> for <tt>CSIDE='L','R', and 'U'</tt>, respectively (with initial values of 1, 1, and 1, respectively), and the attributes are set by inquiring these internal variables. Hereafter, this will be expressed as: The attributes for the angle of rotation of the Y axis title will be set by inquiring the values specified by the internal variables <tt>irotcy(s)</tt> (The initial values are 1, 1, and 1.). Furthermore, the <tt>irotcx(s)</tt> and <tt>irotcy(s)/tt> will be collectively expressed as: The attributes for the angle of rotation of the axis labels will be set by inquiring the values specified by the internal variables <tt>irotc(zs)</tt> (The initial values are 0, 0, 0, 1, 1, and 1.).
(3) Of the attributes, those with <Argument> are set by directly specifying the value of the argument. 

The attributes are actually set by the following method. 
(1)The line segment for axis 
    a. The line index of the line segment <ISLCT>
    A line segment is drawn using the line index specified by the internal variable <tt>indext(i)</tt>. (The initial values are undefined, 1, and 3.)  
(2)The tick marks  
    a. Length of a tick mark <ISLCT>
    Tick marks are drawn using the length (shown in units in VC) specified by the internal variables <tt>rsizet(i)</tt>. (The initial values are undefined, 0.007, and 0.014.)  
    b. The line index for a tick mark <ISLCT>
    Tick marks are drawn using the line index specified by the internal variables <tt>indext(i)</tt>. (The initial values are undefined, 1, and 3.) [Note: The direction the tick marks are drawn is set by the internal variable <tt>inner</tt>. When <tt>inner</tt> has a positive value, the tick marks are drawn towards the inside, and when negative, drawn towards the outside. (The initial value is +1.)]  
(3)Labels 
    a. Character height <ISLCT>
    Characters are drawn using the character height (shown in units in VC) specified by the internal variables <tt>rsizel(i)</tt>. (The initial values are undefined, 0.021, and 0.028.)  
    b. Angle of rotation of text <CSIDE>
    Labels are drawn using the angle of rotation option specified by the internal variables <tt>irotl(zs)</tt>. (The initial values are 0, 0, 0, 0, 0, and 0.) The angle of rotation option is specified by an integer value when a unit of rotation for the label is a rotation of 90 degrees. (For example, when performing a rotation of&nbsp; 90 degrees, specify 1, and when performing a rotation of -90 deg., specify -1.)    
    c. Centering option of text <CSIDE>
    Labels are drawn using the centering option specified by the internal variables <tt>icent(zs)</tt>. (The initial values are 0, 0, 0, +1, +1, ane +1.) The centering option specifies whether the label is drawn by left aligned (-1), centered (0), or right aligned (+1).  
    d. Line index of the line for the text <ISLCT>
    Characters are drawn using the line index specified by the internal variables <tt>indexl(i)</tt>. (The initial values are undefined, 3, and 3.)  
(4)Titles 
    a. Character height <ISLCT>
    Characters are drawn using the character height (in units in VC) specified by the internal variables <tt>rsizec(i)</tt>. (The initial values are undefined, 0.028, and 0.035.)  
    b. Angle of rotation of text <CSIDE>
    Titles are drawn using the angle of rotation option specified by the internal variables <tt>irotc(zs)</tt>. (The initial values are 0, 0, 0, +1, +1, and +1.) The angle of rotation option is specified by an integer value when a unit of rotation for the title is a rotation of 90 degrees. (For example, when performing a rotation of&nbsp; 90 degrees, specify 1, and when performing a rotation of -90 deg., specify -1.)    
    c. Centering option of text <Argument>
    Titles are drawn using the centering option specified by the argument. The centering option specifies whether the label is drawn by left aligned (-1), centered (0), or right aligned (+1).  
    d. Line index of the line for the text&nbsp; <ISLCT>
    Characters are drawn using the line index specified by the internal variables <tt>indexl(i)</tt>. (The initial values are undefined, 3, and 3.) 

===Parameter
Name  Type     DCL package
:ireset(Fixnum)<USPACK>
   A variable for specifying the automatic resetting of parameters with <tt>USINIT</tt>. The initial value is 1.
    * 0: Resets only the variables with *, such as scaling parameters. 
    * 1: In addition to <tt>IRESET=0</tt>, resets the title.
    * 2: Reset all parameters in Axis module.
   USINIT is normally called from Frame.new.
:lxinv(true or false)<USPACK>
   Inverts the X axis (left-right) when true.
:lyinv(true or false)<USPACK>
   Inverts the Y axis (top-bottom) when true.
:lmatch(true or false)<USPACK>
   When true, the intervals of the labels and characters for the X and Y axis are set to be equal.
:rmrgn(Float)<USPACK>
   The width of a margin. Units in width of character (9.524).
:xfac*(Float)<USPACK>
   The value of the X axis factor (999).
:yfac*(Float)<USPACK>
   The value of the Y axis factor (999).
:xoff*(Float)<USPACK>
   The offset value of an uniform X axis (999).
:yoff*(Float)<USPACK>
   The offset value of an uniform Y axis (999).
:dxt*(Float)<USPACK>
   The interval of the tick marks for an uniform X axis (999).
:dyt*(Float)<USPACK>
   The interval of the tick marks for an uniform Y axis (999).
:dxl*(Float)<USPACK>
   The interval of the labels for an uniform X axis (999).
:dyl*(Float)<USPACK>
   The interval of the labels for an uniform Y axis (999).
:tfact(Float)<USPACK>
   The approximate interval of tick marks for an uniform coordinate system (2). A convenient value is selected for DUT, with an interval smaller than this value is multiplied by the character width.
:mxdgtx(Fixnum)<USPACK>
   The maximum number of digits in the label for the uniform X axis (4).
:mxdgty(Fixnum)<USPACK>
   The maximum number of digits in the label for the uniform Y axis (4). When the number of digits in the label exceed this value, set UOFF and UFAC so that the number of digits is lower than this value.
:nblank1(Fixnum)<USPACK>
   The minimum number of blanks between the labels when the labels are parallel to the axis. (Uniform coordinate system) (1).
:nblank2(Fixnum)<USPACK>
   The minimum number of blanks between the labels when the labels are perpendicular to the axis. (Uniform coordinate system) (2).
:nlblx*(Fixnum)<USPACK>
   The label format for a log X axis (999).
:nlbly*(Fixnum)<USPACK>
   The label format for a log Y axis (999).
:nticksx*(Fixnum)<USPACK>
   The number of ticks in a single order for a log X axis (999).
:nticksy*(Fixnum)<USPACK>
   The number of ticks in a single order for a log Y axis (999).
:itypex*(Fixnum)<USPACK>
   The type of log X axis (999).
:itypey*(Fixnum)<USPACK>
   The type of log Y axis (999).
:mxdgtsx(Fixnum)<USPACK>
   When the sub-labels for the X axis are drawn horizontally, they are drawn so that they do not exceed the range of character numbers for the label specified by mxdgtsx.
:mxdgtsy(Fixnum)<USPACK>
   When the sub-labels for the Y axis are drawn vertically, they are drawn so that they do not exceed the range of character numbers for the label specified by mxdgtsy.
:lprtct(true or false)<USPACK>
   Specifies that the sub-labels should not invade the label area for the other axis. When this is true, then the specifications in mxdgtsx/mxdgtsy are ignored.
:soffxtr*, soffxtl*, soffxbr*, soffxbl*, soffxur*, soffxul*(Float)<USPACK>
   The offset value of the X-axis sub-label. 
:soffytr*, soffyrb*, soffylt*, soffylb*, soffyut*, soffyub*(Float)<USPACK>
   The offset value of the Y-axis sub-label.
:xdtmax*, xdtmin*(Float)<USPACK>
   The maximum and minimum values of the X axis set by Fig.inclpoint.
:ydtmax*, ydtmin*(Float)<USPACK>
   The maximum and minimum values of the Y axis set by Fig.inclpoint.
:cxttl(String)<USPACK>
   The X- axis title (shorter than 32 characters)
:cyttl(String)<USPACK>
   The Y- axis title (shorter than 32 characters)
:cxfmt(String)<USPACK>
   >The X-axis label format. (Note 1)
:cyfmt(String)<USPACK>
   The Y-axis label format. (Note 1)
:cxside(String)<USPACK>
   The position to plot the X axis. You may specify this using up to 2 characters out of <tt>'T'(Top), 'B'(Bottom), 'U'(User)</tt>. Of the 2 characters specified, the subtitle and title is written in the position specified first. (Note 2)
:cyside(String)<USPACK>
   The position to plot the Y axis. You may specify this using up to 2 characters out of <tt>'R'(Right), 'L'(Left), 'U'(User)</tt>. Of the 2 characters specified, the subtitle and title is written in the position specified first. (Note 2)
:cxspos(String)<USPACK>
   The position to write the X-axis sub-label: 'R' or 'L'
:cyspos(String)<USPACK>
   The position to write the Y-axis sub-label: 'T' or 'B'
:cxunit(String)<USPACK>
   The unit to write in the X-axis sub-label (shorter than 32 characters)
:cyunit(String)<USPACK>
   The unit to write in the Y-axis sub-label (shorter than 32 characters)
:cblkt(String)<USPACK>
   The brackets for the sub-labels. The initial value is '()' When a blank is specified, no brackets are written.
:labelxb, labelxt, labelxu, labelyl, labelyr, labelyu(true or false)<UZPACK>
   An internal variable which specifies whether or not to draw labels. Labels drawn when <tt>.TRUE.</tt>; not drawn when false. (The initial values are true, false, true, true, false, true) 
:rsizet0, rsize1, rsize2 (Float)<UZPACK>
   An internal variable which specifies the length of the tick mark in units in VC. (The initial values are undefined, 0.007, and 0.014). 
:rsizel0, rsizel1, rsizel2 (Float)<UZPACK>
   An internal variable which specifies the character height of the characters of the label in units in VC. (The initial values are undefined, 0.021, and 0.028.)
:rsizec0, rsizec1, rsizec2 (Float)<UZPACK>
   An internal variable which specifies the character height of the characters of the title in units in VC. (The initial values are undefined, 0.028, and 0.035)
:uxuser(Float)<UZPACK>
   The value of the X coordinate which is used when '<tt>U</tt>'ser is specified as the parameter to specify position in the draw routine of the Y axis. (The initial value is undefined.)
:uyuser(Float)<UZPACK>
   The value of the Y coordinate which is used when '<tt>U</tt>'ser is specified as the parameter to specify position in the draw routine of the X axis. (The initial value is undefined.)
:irotl(zs) (Fixnum) <UZPACK>
   An internal variable which specifies the angle of rotation of the label text. The amount of rotation is specified using integer values when a unit of rotation is 90 degrees. (The initial values are 0, 0, 0, 0, 0, and 0.)
:irotc(zs) (Fixnum) <UZPACK>
   An internal variable which specifies the angle of rotation of the title text. The amount of rotation is specified using integer values when a unit of rotation is 90 degrees. (The initial values are 0, 0, 0, 0, 0, and 0.) 
:icent(zs) (Fixnum) <UZPACK>
   An internal variable which specifies the centering option of the label text. Left-aligned when -1, centered when 0, and right-aligned when +1. (The initial values are 0, 0, 0, +1, +1, and +1.)
:indext(i) (Fixnum) <UZPACK>
   An internal variable which specifies the line index of the line segment for drawing tick marks. (The initial values are undefined, 1, and 3.)
:indexl(i) (Fixnum) <UZPACK>
   An internal variable which specifies the line index of the line segment for characters in labels and text. (The initial values are undefined, 3, and 3.)
:loffset (true or false) <UZPACK>
   An internal variable which specifies whether or not to perform linear offset of the coordinate system. Offset when true; Not offset when false. (The initial value is false.)
:xoffset (Float) <UZPACK>
   An internal variable which specifies the amount of X axis offset when loffset is true. (The initial value is 0.0.)
:yoffset (Float) <UZPACK>
   An internal variable which specifies the amount of Y axis offset when loffset is true. (The initial value is 0.0.)
:xfact (Float) <UZPACK>
   An internal variable which specifies the value of the X axis factor when loffset is true. (The initial value is 1.0.)
:yfact (Float) <UZPACK>
   An internal variable which specifies the value of the Y axis factor when loffset is <tt>.TRUE.</tt>. (The initial value is 1.0.)
:pad1 (Float) <UZPACK>
   An internal variable which specifies the distance between the label and the axis component last drawn. (The initial value is 0.7 when the height of the label to be drawn is 1.)
:pad2 (Float) <UZPACK>
   An internal variable which is used when internally determining the amount of offset for the axis. (The initial value is 1.5, when the size of the internal variable rsizec2 is 1.)
:iflag (Fixnum) <UZPACK>
   An internal variable which specifies on which side of the axis the labels and titles are drawn when the parameter '<tt>U</tt>'ser is used in the axis settings. When iflag is positive, the labels are drawn above the axis for Axis::Lin.xplbl and on the right for Axis::Lin.yplbl. When iflag is negative, the labels are drawn on the opposite sides. (The initial value is -1. )
:lbtwn (true or false) <UZPACK>
   An internal variable which specifies the options for the position to draw the labels. When lbtwn is true, the labels are drawn in between the positions specified and when false, at the positions specified. (The initial value is false.)
:rbtwn (Float) <UZPACK>
   Specifies the detailed position of the label when the labels are drawn in between the positions specified (when lbtwn is true). Left-aligned when -1, centered when 0, right-aligned when +1. (The initial value is 0.0.)
:lbound (true or false) <UZPACK>
   Specifies whether to draw the title when the title exceeds the width of the viewport. Not drawn when true, drawn when false. (The initial value is false.)
:lbmsg (true or false) <UZPACK>
   Specifies whether to print an error message when lbound is true and there is not enough space for the title. Error message printed when true, not printed when false. (The initial value is true.)
:inner (Fixnum) <UZPACK>
   An internal variable which specifies on which side of the axis the tick marks are drawn. When inner is positive, the tick marks are drawn on the outside, and when negative, drawn on the inside. (The initial value is +1.)
:iundef (Float) <UZPACK>
   An internal variable which indicates that the value is undefined. (The initial value is -999.)

(1) When these formats are specified explicitly, <tt>DXL</tt> and <tt>DYL</tt> must be specified accordingly since this information is not reflected in label intervals. 
(2) When the label(zs) of the first position specified by the internal variables cxside and cyside is false, then neither the subtitle or title is written.

In addition, These parameters can be used as methods. For example, it is possible to refer the parameter "ireset" with Axis.ireset method. Moreover, it is possible to set the parameter "ireset" with Axis.ireset= method.

=end
#japanese
=begin
==NumRu::AdvancedDCL::Axis
=={W[ɂ
AxisW[͎Ŏ`߂̃W[łB
===W̏ꏊ
Axis, Axis::Lin, Axis::Log g߂ɂ, 炩ߕϊ֐ԍ 1`4 (pWn)̐Kϊݒ肳ĂȂ΂ȂȂ ( ((<{Ců{\>)) Q). Ƃ 
  Fig.viewport=[VXMIN,VXMAX,VYMIN,VYMAX]
  Fig.window=[UXMIN,UXMAX,UYMIN,UYMAX] 
  Fig.transnum=ITR
ĂłƂ. ̂Ƃ Axis::Lin ͎̏ꏊɍWݒł. 

XɂĂ 
  'B'ottom - (UXMIN, UYMIN) (UXMAX, UYMIN)Ԑ
  'T'op - (UXMIN, UYMAX) (UXMAX, UYMAX)Ԑ
  'U'ser - (UXMIN, UYUSER) (UXMAX, UYUSER)Ԑ

YɂĂ
  'L'eft - (UXMIN, UYMIN) (UXMIN, UYMAX)Ԑ
  'R'ight - (UXMAX, UYMIN) (UXMAX, UYMAX)Ԑ
  'U'ser - (UXUSER, UYMIN) (UXUSER, UYMAX)Ԑ

XɊւ'B', 'T', 'U', YɊւ'L', 'R', 'U', W̍\vf(ߎQ)悷ꏊ߂̃p[^[(CSIDE)Ƃėp. UXUSER, UYUSER̓p^ uxuser, uyuser ݒ肵ď߂ėLƂȂ(l͕s). Wݒł邱̏ꏊ, XɂĂ Axis::Lin.xsaxs ɂ Yɕsړ邱Ƃł; YɂĂ Axis::Lin.ysaxs ɂ Xɕsړ邱Ƃł. 

===W̍\vfƂ̑
Axis::Lin 悷W̍\vfɂ͎̂̂ (JbR͂̍\vf`Tu[`). 
  (1)  (Axis::Lin.xpaxs/ypaxs) 
  (2) ڐ (Axis::Lin.xptmk/yptmk) 
  (3) x 
      * Ŏw (Axis::Lin.xplbl/yplbl) 
      * lŎw (Axis::Lin.xpnum/ypnum) 
  (4) ^Cg (Axis::Lin.xpttl/ypttl) 

ꂼ̍\vf͎̂悤ȑĂ. 
  (1) ɂĂ 
        a. ̃CCfNX <ISLCT>
  (2) ڐɂĂ 
        a. ڐ̒ <ISLCT>
        b. ڐ`̃CCfNX <ISLCT>
  (3) xɂĂ 
        a. ̍ <ISLCT>
        b. ̉]p <CSIDE>
        c. ̃Z^OIvV <CSIDE>
        d. `̃CCfNX <ISLCT>
  (4) ^CgɂĂ 
        a. ̍ <ISLCT>
        b. ̉]p <CSIDE>
        c. ̃Z^OIvV <>
        d. `̃CCfNX <ISLCT>

̑̎w@ <ISLCT>, <CSIDE>, <> ӖɂĂ͎߂ŏqׂ. 

W̐ݒ'U'serȊOłȂꍇ, xƃ^Cg͏ɃEChE̊OɌĕ`. 'U'serŐݒȂꍇ, xƃ^Cĝǂ瑤ɏ ϐ'IFLAG'߂.

===̎w@
Axis::Lin ̊eTu[`ɂISLCT, CSIDEƂ2̈. 2̈т̑̈e\vf̑߂. 
(1) ISLCT0,1,2̒lƂ肤. 3.3߂ŏqׂ ̂<ISLCT>Ƃ̂,̈ɂĒ܂p^QƂČ܂.
    ISLCT=0,1,2̋̓IȈӖ, 
    * ISLCT=0 : [U[`ϐgč悷. 
    * ISLCT=1 : ̃pbP[W炩ߐݒ肵Ă ϐgč悷. ߂̖ڐ, x, ^Cg`Ƃɗp. 
    * ISLCT=2 : ̃pbP[W炩ߐݒ肵Ă ϐgč悷. 傫߂̖ڐ, x, ^Cg`Ƃɗp. 
             
Ƃ, ̃CCfNXɂĂ, ISLCT=0,1,2ꂼɂ indext0, indext1, indext2 Ƃp^(l͏, s, 1, 3) QƂđ܂. ȉł͈ȏ̕\܂Ƃ߂Ď̂悤ɗL. -- up^ index(i) Ŏw肵ĂlQƂăCCfNX̑܂(l, s, 1, 3)v. ̃p^ Axis::Lin.get, Axis::Lin.set ɂ Q/ύXł. 
(2) CSIDE͍\vf`ꏊw肷ƂƂ, `ꏊɈˑ鑮߂. O߂ŏqׂ̂<CSIDE>Ƃ̂, ̈ɂĒ܂p^QƂČ܂. Ƃ, Xɂ^Cg̉]pɂĂ, CSIDE='B','T','U'ꂼɂ irotcxb, irotcxt, irotcxu Ƃp^(l͏, 0, 0, 0) QƂđ܂. ȉł͈ȏ̕\܂Ƃ߂Ď̂悤ɗL. -- up^ irotcx(s) Ŏw肵ĂlQƂ, Xɂ^Cg̉]pɊւ鑮܂(l, 0, 0, 0)v. ܂, Yɂ^Cg̉]pɂĂ, CSIDE='L','R','U'ꂼɂ irotcyl, irotcyr, irotcyu Ƃp^(l͏, 1, 1, 1) QƂđ܂. ȉł͈ȏ̕\܂Ƃ߂Ď̂悤ɗL. -- up^ irotcy(s) Ŏw肵ĂlQƂ, Yɂ^Cg̉]pɊւ鑮܂(l, 1, 1, 1)v.  irotcx(s)  irotcy(s) ܂Ƃ߂Ď̂悤ɗL. -- up^ irotc(zs) Ŏw肵ĂlQƂ,ɂ郉x̉]pɊւ鑮܂(l, 0, 0, 0, 1, 1, 1)v. 
(3) O߂ŏqׂ̂<>Ƃ̂, ƂĒڎw肷邱ƂɂČ܂. 

O߂ŏqׂ͋̓IɎ̂悤Ɍ܂. 
(1) ɂĂ 
      a. ̃CCfNX <ISLCT> 
      p^ indext(i)Ŏw肵Ă郉CCfNXpĐ` (l, s, 1, 3). 
(2) ڐɂĂ 
      a. ڐ̒ <ISLCT> 
p^ rsizet(i)Ŏw肵Ă钷(PʂVWn)̖ڐ` (l, s, 0.007, 0.014). 
      b. ڐ`̃CCfNX <ISLCT> 
p^ indext(i)Ŏw肵Ă郉CCfNXpĖڐ` (l, s, 1, 3). (:ڐ`̓p^ inner ߂. inner ̂ƂɌĖڐ`; ̂ƂOɌĖڐ`(l+1). ) 
(3) xɂĂ 
      a. ̍ <ISLCT> 
p^ rsizel(i) Ŏw肵Ă鍂(PʂVWn)̕` (l, s, 0.021, 0.028). 
      b. ̉]p <CSIDE> 
p^ irotl(zs) Ŏw肵Ă]pIvVgăx`(l, 0, 0, 0, 0, 0, 0). ]pIvVƂ,x`Ƃ̉]p90x 1Pʂ̐lŎw肷̂ł. (Ƃ90x̂Ƃ1, -90x̂Ƃ-1Ǝw肷.) 
      c. ̃Z^OIvV <CSIDE> 
p^ icent(zs) Ŏw肵ĂZ^OIvVgăx`(l, 0, 0, 0, +1, +1, +1). Z^OIvVƂ, x`Ƃɍ悹(-1)邩, Z^O(0)邩, E悹(+1)邩w肷̂ł. 
      d. `̃CCfNX <ISLCT> 
p^ indexl(i) Ŏw肵Ă郉CCfNXpĕ` (l, s, 3, 3). 
(4) ^CgɂĂ 
      a. ̍ <ISLCT> 
p^ rsizec(i) Ŏw肵Ă鍂(PʂVWn)̕` (l, s, 0.028, 0.035). 
      b. ̉]p <CSIDE> 
p^ irotc(zs) Ŏw肵Ă]pIvVgăx`(l, 0, 0, 0, +1, +1, +1). ]pIvVƂ, ^Cg`Ƃ̉]p90x 1Pʂ̐lŎw肷̂ł. (Ƃ90x̂Ƃ1, -90x̂Ƃ-1Ǝw肷. ) 
      c. ̃Z^OIvV <> 
Ŏw肵ĂZ^OIvV gă^Cg`. Z^OIvVƂ, x`Ƃɍ悹(-1)邩, Z^O(0)邩, E悹(+1)邩w肷̂ł. 
      d. `̃CCfNX <ISLCT> 
p^ indexl(i) Ŏw肵Ă郉CCfNXpĕ` (l, s, 3, 3).
 
===p^
p^ p^̌^ ΉDCLpbP[W
:ireset(Fixnum)<USPACK>
   USINITŎIɃp[^ Zbg邱Ƃw肷ϐ. l1. 
    * 0: XP[Op^Ȃ ( * ̂ϐ) ̃ZbĝݍsȂ. 
    * 1: ireset=0 ɉă^Cg̃Zbg. 
    * 2: AxiŝׂẴp^ Zbg. 
   USINIT͒ʏ Frame.newĂ΂.
:lxinv(true or false)<USPACK>
   TRUE̎, X̍Etɂ.
:lyinv(true or false)<USPACK>
   TRUE̎, Y̏㉺tɂ.
:lmatch(true or false)<USPACK>
   TRUE̎, XỸxԊuy Ԋu𓯂ɂ.
:rmrgn(Float)<USPACK>
   }[W̕. Pʂ͕. (9.524)
:xfac*(Float)<USPACK>
   XW̃t@N^[l (999.)
:yfac*(Float)<USPACK>
   YW̃t@N^[l (999.)
:xoff*(Float)<USPACK>
   lXW̃ItZbgl (999.)
:yoff*(Float)<USPACK>
   lYW̃ItZbgl (999.)
:dxt*(Float)<USPACK>
   lXW̖ڐ̊Ԋu (999.)
:dyt*(Float)<USPACK>
   lYW̖ڐ̊Ԋu (999.)
:dxl*(Float)<USPACK>
   lXW̃x̊Ԋu (999.)
:dyl*(Float)<USPACK>
   lYW̃x̊Ԋu (999.)
:tfact(Float)<USPACK>
   lW̖ڐԊu̖ڈ (2).̒lɕ ( rsize1) | ȊԊu, ؂̂悢ldutƂĐݒ肷.
:mxdgtx(Fixnum)<USPACK>
   lXW̃x̍ő包 (4)
:mxdgty(Fixnum)<USPACK>
   lYW̃x̍ő包 (4).x̌̒l傫ȂƂ, uoff, ufac ݒ肵 ̌ȓɂ܂悤Ɏ݂.
:nblank1(Fixnum)<USPACK>
   xWƕsȏꍇ, xԂ̍ŏ󔒐. (lW) (1)
:nblank2(Fixnum)<USPACK>
   xWƒpȏꍇ, xԂ̍ŏ󔒐. (lW) (2)
:nlblx*(Fixnum)<USPACK>
   ΐXW̃x` (999)
:nlbly*(Fixnum)<USPACK>
   ΐYW̃x` (999)
:nticksx*(Fixnum)<USPACK>
   ΐXẄꌅ̊Ԃ̖ڐ̐ (999)
:nticksy*(Fixnum)<USPACK>
   ΐYẄꌅ̊Ԃ̖ڐ̐ (999)
:itypex*(Fixnum)<USPACK>
   ΐXW̃^Cv (999)
:itypey*(Fixnum)<USPACK>
   ΐYW̃^Cv (999)
:mxdgtsx(Fixnum)<USPACK>
   X̃Tux̏ꍇ, mxdgtsxŎw肳ꂽ̃x͈̔͂ zȂ悤ɃTux`.
:mxdgtsy(Fixnum)<USPACK>
   ỸTux̏ꍇ, mxdgtsyŎw肳ꂽ̃x͈̔͂ zȂ悤ɃTux`.
:lprtct(true or false)<USPACK>
   Tux𑼕̎̃ẍ ܂ŕ`ȂƂw肷. ꂪ TRUE̎ɂ mxdgtsx/mxdgtsy ̎w͖.
:soffxtr*, soffxtl*, soffxbr*, soffxbl*, soffxur*, soffxul*(Float)<USPACK>
   X̃Tux̃ItZbgl. 
:soffytr*, soffyrb*, soffylt*, soffylb*, soffyut*, soffyub*(Float)<USPACK>
   ỸTux̃ItZbgl. 
:xdtmax*, xdtmin*(Float)<USPACK>
   Fig.inclpoint Őݒ肳ꂽ x W̍őŏl.
:ydtmax*, ydtmin*(Float)<USPACK>
   Fig.inclpoint Őݒ肳ꂽ y W̍őŏl.
:cxttl(String)<USPACK>
   X̃^Cg (32ȓ)
:cyttl(String)<USPACK>
   Ỹ^Cg (32ȓ)
:cxfmt(String)<USPACK>
   X̃x̃tH[}bg (1)
:cyfmt(String)<USPACK>
   Ỹx̃tH[}bg (1)
:cxside(String)<USPACK>
   Xʒu. 'T'(Top), 'B'(Bottom), 'U'(User) ̂ 2܂Ŏwł. 2̈ʒûŏɎw肵ʒu Tuxƃ^Cg. (2)
:cyside(String)<USPACK>
   Y`ʒu. 'R'(Right), 'L'(Left), 'U'(User) ̂ 2܂Ŏwł. 2̈ʒûŏɎw肵ʒu Tuxƃ^Cg. (2)
:cxspos(String)<USPACK>
   X̃Tuxʒu 'R' ܂ 'L'
:cyspos(String)<USPACK>
   ỸTuxʒu 'T' ܂ 'B'
:cxunit(String)<USPACK>
   X̃TuxɏP (32ȓ)
:cyunit(String)<USPACK>
   ỸTuxɏP (32ȓ)
:cblkt(String)<USPACK>
   ỸTuxɏP (32ȓ)
:labelxb(true or false)<UZPACK>
   x`ǂw肷ϐ;TRUEȂ`, FALSEȂ`Ȃ(TRUE)
:labelxt(true or false)<UZPACK>
   x`ǂw肷ϐ;TRUEȂ`, FALSEȂ`Ȃ(FALSE)
:labelxu(true or false)<UZPACK>
   x`ǂw肷ϐ;TRUEȂ`, FALSEȂ`Ȃ(TRUE)
:labelyl(true or false)<UZPACK>
   x`ǂw肷ϐ;TRUEȂ`, FALSEȂ`Ȃ(TRUE)
:labelyr(true or false)<UZPACK>
   x`ǂw肷ϐ;TRUEȂ`, FALSEȂ`Ȃ(FALSE)
:labelyu(true or false)<UZPACK>
   x`ǂw肷ϐ;TRUEȂ`, FALSEȂ`Ȃ(TRUE)
:rsizet0(Float)<UZPACK>
   ڐ̒w肷ϐ(PʂVWn)(s)
:rsizet1(Float)<UZPACK>
   ڐ̒w肷ϐ(PʂVWn)(0.007)
:rsizet2(Float)<UZPACK>
   ڐ̒w肷ϐ(PʂVWn)(0.014)
:rsizel0(Float)<UZPACK>
   x̍̕w肷ϐ(PʂVWn)(s)
:rsizel1(Float)<UZPACK>
   x̍̕w肷ϐ(PʂVWn)(0.021)
:rsizel2(Float)<UZPACK>
   x̍̕w肷ϐ(PʂVWn)(0.028)
:rsizec0(Float)<UZPACK>
   ^Cg̍̕w肷ϐ(PʂVWn)(s)
:rsizec1(Float)<UZPACK>
   ^Cg̍̕w肷ϐ(PʂVWn)(0.028)
:rsizec2(Float)<UZPACK>
   ^Cg̍̕w肷ϐ(PʂVWn)(0.035)
:uxuser(Float)<UZPACK>
   Y̍惋[`ɂďꏊp[^[Ƃ'U'serw肵ƂɗpXWl(l͕s). 
:uyuser(Float)<UZPACK>
   X̍惋[`ɂďꏊp[^[Ƃ'U'serw肵ƂɗpYWl(l͕s). 
:irotl(zs) (Fixnum) <UZPACK>
   x̉̕]pw肷p^; ]p90xPʂƂ鐮lŎw肷(l, 0, 0, 0, 0, 0, 0). DCL manual 3.4, 3.8.3ߎQ.
:irotc(zs) (Fixnum) <UZPACK>
   ^Cg̉̕]pw肷p^; ]p90xPʂƂ鐮lŎw肷(l, 0, 0, 0, +1, +1, +1). DCL manual 3.4, 3.8.5ߎQ.
:icent(zs) (Fixnum) <UZPACK>
   x̃̕Z^OIvVw肷p^; -1̂Ƃ悹, 0̂ƂZ^O,+1̂ƂE悹(l, 0, 0, 0, +1, +1, +1). DCL manual 3.4, 3.8.3ߎQ.
:indext(i) (Fixnum) <UZPACK>
   Wіڐ`̃CCfNXw肷p^(l, s, 1, 3). DCL manual 3.4, 3.8.2ߎQ.
:indexl(i) (Fixnum) <UZPACK>
   xу^Cg̕`̃CCfNXw肷p^(l, s, 3, 3). DCL manual 3.4, 3.8.3ߎQ.
:loffset (true or false) <UZPACK>
   WnjAItZbg邩ǂw肷p^. true Ȃ烊jAItZbg; false Ȃ炵Ȃ(l false). DCL manual 3.6ߎQ.
:xoffset (Float) <UZPACK>
   loffset  true ̂Ƃ,X̃ItZbglw肷p^(l0.0). DCL manual 3.6ߎQ.
:yoffset (Float) <UZPACK>
   loffset  true ̂Ƃ,ỸItZbglw肷p^(l0.0). DCL manual 3.6ߎQ.
:xfact (Float) <UZPACK>
   loffset  true ̂Ƃ,X̃t@N^[lw肷p^(l1.0). DCL manual 3.6ߎQ.
:yfact (Float) <UZPACK>
   loffset  true ̂Ƃ,Ỹt@N^[lw肷p^(l1.0). DCL manual 3.6ߎQ.
:pad1 (Float) <UZPACK>
   1Oɕ`W̍\vfǂꂾăx`w肷p^(l0.7; Pʂ͍`ƂĂ郉x̍1Ƃ).
:pad2 (Float) <UZPACK>
   W̃ItZbgʂIɌ߂鎞ɗpp^(l1.5; Pʂ̓p^ rsizec2 ̑傫1Ƃ).
:iflag (Fixnum) <UZPACK>
   W̐ݒ'U'serłȂꍇ,xƃ^Cĝǂ瑤ɕ`w肷p^. iflag ̂Ƃx Axis::Lin.xplbl ɂĂ͏㑤, Axis::Lin.yplbl ɂĂ͉Eɕ`.̂Ƃ͂̋tł. (l-1). DCL manual 3.8.3ߎQ.
:lbtwn (true or false) <UZPACK>
   x`ꏊɊւIvVw肷p^. lbtwn  true ȂԂɕ`; false Ȃ炻̏ꏊɕ`(l false). DCL manual 3.8.3ߎQ.
:rbtwn (Float) <UZPACK>
   xԂɕ`Ƃ( lbtwn  true ̂Ƃ),ɂ̈ʒuڂw肷. -1.0̂Ƃ悹, 0.0̂ƂZ^O, +1.0̂ƂE悹(l0.0).
:lbound (true or false) <UZPACK>
   ^Cg`Ƃ, r[|[g̕zĂ܂悤ȂƂ,^Cg`ǂw肷. true Ȃ`Ȃ, false Ȃ`(l false).
:lbmsg (true or false) <UZPACK>
   lbound  true Ń^Cg`Xy[XȂƂ,G[bZ[Wo͂邩ǂw肷. true Ȃo͂, false Ȃo͂Ȃ(l true).
:inner (Fixnum) <UZPACK>
   ڐɌđł,OɌđłw肷p^. inner ̂ƂɌĖڐł; ̂ƂOɌĖڐł(l+1).
:iundef (Float) <UZPACK>
   lsł邱Ƃp^(l-999).
:cxfmt (String) <UXPACK::UXSFMT>

(1) ̃tH[}bgzɎw肵ꍇ, x̊ԊuȂǂɂ͔̏fȂ̂, dxl, dyl K؂Ɏw肵Ȃ,xdȂꍇ. 
(2)ϐ cxside, cyside Ŏw肳ŏ̈ʒu label(zs)FALSE̎ɂ, Tux, ^CgƂɕ`Ȃ. 

܂Ãp^̓\bhƂėp邱ƂłBȂ킿AAxis.iresetŃp^ireset̎QƂAAxis.ireset=Ńp^ireset̕ύXłB

=end

module NumRu
  module AdvancedDCL
    module Axis
      def param_init
	@param = Parameter.new(Common.param)
	
	@param.init("ireset", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("lxinv", TrueClass, "uslset", "uslget", 0, 0)
	@param.init("lyinv", TrueClass, "uslset", "uslget", 0, 0)
	@param.init("lxsub", TrueClass, "uslset", "uslget", 0, 0)
	@param.init("lysub", TrueClass, "uslset", "uslget", 0, 0)
	@param.init("lmatch", TrueClass, "uslset", "uslget", 0, 0)
	@param.init("rmrgn", Float, "usrset", "usrget", 0, 0)
	@param.init("xfac", Float, "usrset", "usrget", 0, 0)
	@param.init("yfac", Float, "usrset", "usrget", 0, 0)
	@param.init("xoff", Float, "usrset", "usrget", 0, 0)
	@param.init("yoff", Float, "usrset", "usrget", 0, 0)
	@param.init("dxt", Float, "usrset", "usrget", 0, 0)
	@param.init("dyt", Float, "usrset", "usrget", 0, 0)
	@param.init("dxl", Float, "usrset", "usrget", 0, 0)
	@param.init("dyl", Float, "usrset", "usrget", 0, 0)
	@param.init("tfact", Float, "usrset", "usrget", 0, 0)
	@param.init("mxdgtx", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("mxdgty", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("nblank1", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("nblank2", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("nlblx", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("nlbly", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("nticksx", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("nticksy", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("itypex", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("itypey", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("mxdgtsx", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("mxdgtsy", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("lprtct", TrueClass, "uslset", "uslget", 0, 0)
	@param.init("soffxtr", Float, "usrset", "usrget", 0, 0)
	@param.init("soffxtl", Float, "usrset", "usrget", 0, 0)
	@param.init("soffxbr", Float, "usrset", "usrget", 0, 0)
	@param.init("soffxbl", Float, "usrset", "usrget", 0, 0)
	@param.init("soffxur", Float, "usrset", "usrget", 0, 0)
	@param.init("soffxul", Float, "usrset", "usrget", 0, 0)
	@param.init("soffyrt", Float, "usrset", "usrget", 0, 0)
	@param.init("soffyrb", Float, "usrset", "usrget", 0, 0)
	@param.init("soffylt", Float, "usrset", "usrget", 0, 0)
	@param.init("soffylb", Float, "usrset", "usrget", 0, 0)
	@param.init("soffyut", Float, "usrset", "usrget", 0, 0)
	@param.init("soffyub", Float, "usrset", "usrget", 0, 0)
	@param.init("xdtmax", Float, "usrset", "usrget", 0, 0)
	@param.init("xdtmin", Float, "usrset", "usrget", 0, 0)
	@param.init("ydtmax", Float, "usrset", "usrget", 0, 0)
	@param.init("ydtmin", Float, "usrset", "usrget", 0, 0)
	
	@param.init("cxttl", String, "uscset", "uscget", 0, 0)
	@param.init("cyttl", String, "uscset", "uscget", 0, 0)
	@param.init("cxfmt", String, "uscset", "uscget", 0, 0)
	@param.init("cyfmt", String, "uscset", "uscget", 0, 0)
	@param.init("cxside", String, "uscset", "uscget", 0, 0)
	@param.init("cyside", String, "uscset", "uscget", 0, 0)
	@param.init("cxspos", String, "uscset", "uscget", 0, 0)
	@param.init("cyspos", String, "uscset", "uscget", 0, 0)
	@param.init("cxunit", String, "uscset", "uscget", 0, 0)
	@param.init("cyunit", String, "uscset", "uscget", 0, 0)
	@param.init("cblkt", String, "uscset", "uscget", 0, 0)
	
      #-------- uzpack parameter ---------
	@param.init("labelxb", TrueClass, "uzlset", "uzlget", 0, 0)
	@param.init("labelxt", TrueClass, "uzlset", "uzlget", 0, 0)
	@param.init("labelxu", TrueClass, "uzlset", "uzlget", 0, 0)
	@param.init("labelyl", TrueClass, "uzlset", "uzlget", 0, 0)
	@param.init("labelyr", TrueClass, "uzlset", "uzlget", 0, 0)
	@param.init("labelyu", TrueClass, "uzlset", "uzlget", 0, 0)
	
	@param.init("irotlxb", Fixnum, "uziset", "uziget", 0, 0)
	@param.init("irotlxt", Fixnum, "uziset", "uziget", 0, 0)
	@param.init("irotlxu", Fixnum, "uziset", "uziget", 0, 0)
	@param.init("irotlyl", Fixnum, "uziset", "uziget", 0, 0)
	@param.init("irotlyr", Fixnum, "uziset", "uziget", 0, 0)
	@param.init("irotlyu", Fixnum, "uziset", "uziget", 0, 0)
	
	 @param.init("irotcxb", Fixnum, "uziset", "uziget", 0, 0)
	 @param.init("irotcxt", Fixnum, "uziset", "uziget", 0, 0)
	 @param.init("irotcxu", Fixnum, "uziset", "uziget", 0, 0)
	 @param.init("irotcyl", Fixnum, "uziset", "uziget", 0, 0)
	 @param.init("irotcyr", Fixnum, "uziset", "uziget", 0, 0)
	 @param.init("irotcyu", Fixnum, "uziset", "uziget", 0, 0)
	 
	 @param.init("icentxb", Fixnum, "uziset", "uziget", 0, 0)
	 @param.init("icentxt", Fixnum, "uziset", "uziget", 0, 0)
	 @param.init("icentxu", Fixnum, "uziset", "uziget", 0, 0)
	 @param.init("icentyl", Fixnum, "uziset", "uziget", 0, 0)
	 @param.init("icentyr", Fixnum, "uziset", "uziget", 0, 0)
	 @param.init("icentyu", Fixnum, "uziset", "uziget", 0, 0)
	 
	@param.init("rsizet0", Float, "uzrset", "uzrget", 0, 0)
	@param.init("rsizet1", Float, "uzrset", "uzrget", 0, 0)
	@param.init("rsizet2", Float, "uzrset", "uzrget", 0, 0)
	
	@param.init("rsizel0", Float, "uzrset", "uzrget", 0, 0)
	@param.init("rsizel1", Float, "uzrset", "uzrget", 0, 0)
	@param.init("rsizel2", Float, "uzrset", "uzrget", 0, 0)
	
	@param.init("rsizec0", Float, "uzrset", "uzrget", 0, 0)
	@param.init("rsizec1", Float, "uzrset", "uzrget", 0, 0)
	@param.init("rsizec2", Float, "uzrset", "uzrget", 0, 0)
	
	@param.init("uxuser", Float, "uzrset", "uzrget", 0, 0)
	@param.init("uyuser", Float, "uzrset", "uzrget", 0, 0)

	 @param.init("pad1", Float, "uzrset", "uzrget", 0, 0)
	 @param.init("pad2", Float, "uzrset", "uzrget", 0, 0)
	 
	 @param.init("iflag", Fixnum, "uziset", "uziget", 0, 0)
	 @param.init("lbtwn", TrueClass, "uzlset", "uzlget", 0, 0)
	 @param.init("rbtwn", Float, "uzrset", "uzrget", 0, 0)
	 @param.init("lbound", TrueClass, "uzlset", "uzlget", 0, 0)
	 @param.init("lbmsg", TrueClass, "uzlset", "uzlget", 0, 0)
	 @param.init("inner", Fixnum, "uziset", "uziget", 0, 0)
	 
	 @param.init("cxfmt", String, "uxsfmt", "uxqfmt", 1, 1)
	 @param.init("cyfmt", String, "uysfmt", "uyqfmt", 1, 1)
	 
	 @param.init("roffxu", Float, "uzrset", "uzrget", 0, 0)
	 @param.init("roffyu", Float, "uzrset", "uzrget", 0, 0)
	 @param.init("rofgxb", Float, "uzrset", "uzrget", 0, 0)
	 @param.init("rofgxt", Float, "uzrset", "uzrget", 0, 0)
	 @param.init("rofgxu", Float, "uzrset", "uzrget", 0, 0)
	 @param.init("rofgyl", Float, "uzrset", "uzrget", 0, 0)
	 @param.init("rofgyr", Float, "uzrset", "uzrget", 0, 0)
	 @param.init("rofgyu", Float, "uzrset", "uzrget", 0, 0)
	 
	 @param.init("roffxt", Float, "uzrset", "uzrget", 0, 0)
	 @param.init("roffxb", Float, "uzrset", "uzrget", 0, 0)
	 @param.init("roffyl", Float, "uzrset", "uzrget", 0, 0)
	 @param.init("roffyr", Float, "uzrset", "uzrget", 0, 0)
	 @param.init("iundef", Fixnum, "uziset", "uziget", 0, 0)
	 
	 @temp_param = @param.dup
	 @backup = @param.dup
	@orig_param = @param.dup
	@set = Hash.new
      end
    
      private :param_init

      def param
	@param
      end
#------------------- method for parameters----------------------

      include Parameter_appli

# by kawanabe
#english
=begin
---Axis.set(key, val)
   Sets parameters. If val is nil, the value of the parameter will return default value in DCL.

   Arguments
   * key: parameter name(String)
   * val: new value. About type, refer each parameter.

   Example
      Axis.set("cxttl", "xtitle")      # Sets the title of X axis "xtitle".

=end
=begin
---Axis.set(key, val)
    p^̐ݒsBvalnilw肷ƒlDCLɂ鏉lɖ߂B

    
    * key:p^(String)
    * val:ݒ肷lB^͊ep^QƂ̂ƁB
    gp
        Axis.set("cxttl", "xtitle")      # X̃^Cg"xtitle"ɐݒ

=end

# by kawanabe
#english
=begin
---Axis.get(key)
    Refers the value of the parameter.

    Arguments
    * key: parameter name(String)

    Example
        Axis.get("cxttl")      # Refers the title of X axis.

=end
#japanese
=begin
---Axis.get(key)
    p^QƂB

    
    * key:p^(String)
    gp
        Axis.get("cxttl")      #X̃^CgQƂB

=end

# by kawanabe
#english
=begin
---Axis.reset(key)
    Sets the value of the parameter default value.

    Arguments
    * key: parameter name(String)

    Example
        Arrow.reset("cxttl")      # Sets the title of X axis a default value.

=end
#japanese
=begin
---Axis.reset(key, val)
    p^DCLɂ鏉lɖ߂B

    
    * key:p^(String)
    * val:ݒ肷lB^͊ep^QƂ̂ƁB

    gp
        Axis.reset("cxttl")      # X̃^Cglɖ߂

=end

#english
=begin
---Axis.help_params
    Refers available parameters in Axis module.

    Arguments
     None

    Notes
    (1)This method return name of the parameter, present value, type of the parameter.

=end
#japanes
=begin
---Axis.help_params
    AxisŐݒ\ȃp^QƂB

    
    Ȃ

    l
    (1)̃\bh͐ݒ\ȃp^ɊւāAp^A݂̒lAp^̌^ԂB

=end

#english
=begin
---Axis.sync
    Synchronizes the value of a parameter in DCL with the present value of the parameter in AdvancedDCL.

    Arguments
     None

    Notes
     In AdvancedDCL, parameters which set with "set" method do not synchronize with DCL and a method to synchronize parameters is called in drawing methods. This method is used to synchronize parameters with these of DCL directly.

=end 
#japanese
=begin
---Axis.sync
    ݁Aݒ肳Ăp^DCLɔfB

    
     Ȃ

    l
     AdvancedDCLɂĂset\bĥ݂ł̓p^DCLɔfꂸA
p^sync郁\bhŌĂłB̃\bh̓[Up
^zsyncł邽߂̃\bhłB

=end

      def zfact(rfact)
	@param["rsizet1"] = @param["rsizet1"] * rfact
	@param["rsizet2"] = @param["rsizet2"] * rfact 
	@param["rsizel1"] = @param["rsizel1"] * rfact
	@param["rsizel2"] = @param["rsizel2"] * rfact
	@param["rsizec1"] = @param["rsizec1"] * rfact
	@param["rsizec2"] = @param["rsizec2"] * rfact
	nil
      end

# by DCL manual
#english
=begin
---Axis.zfact(rfact)
    Multiplies all of the internal variables rsizet(i), rsizel(i) and rsizec(i) (i=1,2) by a certain factor.

    Arguments
    *  rfact: The floating-point number for the factor.(Float or Fixnum)

    Notes
    (1)UZFACT is called in this method.

=end
#japanese
=begin
---Axis.zfact(rfact)
    p^ 'rsize(i)', 'rsize(i)', 'rsizec(i)' (i=1,2) ׂĉ{.

    
    * rfact: {邩w肷l.(Float or Fixnum)

    l
    (1)̃\bhUZFACTĂłB

=end

      def title(cxttl, cxunit, cyttl, cyunit)
	DCL.ussttl(cxttl, cxunit, cyttl, cyunit)
	nil
      end

# by DCL manual
#english
=begin
---Axis.title(cxttl, cxunit, cyttl, cyunit)
    Specifies the title of the coordinate axis and the unit in the sub-label drawn by Axis.draw

    Arguments
    * cxttl: The title of the X axis. (String)
    * cxunit: The unit of the X axis. (String)
    * cyttl: The title of the Y axis. (String)
    * cyunit: The unit of the Y axis (String)
    
    Notes
    (1)USSTTL is called in this method.
    (2)When you do not wish to put a title, specify a blank space more than 1 character long. 

=end
#japanese
=begin
---Axis.title(cxttl, cxunit, cyttl, cyunit)
    Axis.drawŏW̃^Cgy Tux̒̒Pʂw肷.

    
    * cxttl: XW̃^Cg (String)
    * cxunit: XW̒P (String)
    * cyttl: YW̃^Cg (String)
    * cyunit: YW̒P (String)
    
    l
    (1)̃\bhUSSTTLĂłB
    (2)^CgtȂƂɂ, 1ȏ̃uNw肷. 

=end

      def xpttl(cside, islct, cttl, px, temp=nil)
	@param.sync
	if(temp)
	   @temp_param.set(temp, @param, @backup)
	   @temp_param.sync
	end

	DCL.uxpttl(cside, islct, cttl, px)

	if(temp)
	   @backup.sync
	   @temp_param.clear
	end
	nil
      end

# by DCL manual
#english
=begin
---Axis.xpttl(cside, islct, cttl, px, temp=nil)
    Draws a title. 

    Arguments
    * cside (String) : Specifies the position of the axis to draw the title. ('B','T','U')
    * islct (Fixnum) : Specifies the attributes of the title to be drawn.
    * cttl (String) : The title to be drawn.
    * px (Fixnum) : Specifies the position to draw the title with a floating-point value between -1 and +1. Left-aligned when -1, centered when 0, and right-aligned when +1.
    * temp (Hash) : temporary parameters.

    Notes
    (1)UXPTTL is called in this method.
    (2)The character size of the title is specified by the internal variable rsizec(i).
    (3)The angle of rotation of the title text is specified by the internal variable irotc(zs).
    (4)The line index of the line for the characters in the title is specified by the internal variable indexl(i).
    (5)When the internal variable lbound is true and the title exceeds the width of the window, the title is not drawn. When lbound is false, the title is drawn when when it exceeds the window width. (The initial value is false.) Also, when the internal variable lbound is true, the title exceeds the window width so it&nbsp; cannot be drawn, a message will be printed if the internal variable lbmsg is true, and will not be printed when false. (The initial value is true.)

=end
#japanese
=begin
---Axis.xpttl(cside, islct, cttl, px, temp=nil)
    ^Cg`. 

     
    * cside (String) : W`ꏊw肷 ('B','T','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UXPTTL ĂłB
    (2)^Cg̑̕傫̓p^ rsizec(i) ߂. 
    (3)^Cg̉̕]p̓p^ irotc(zs) ߂. 
    (4)^Cg̕`̃CCfNX̓p^ indexl(i)߂. 
    (5)p^ lbound  true  ^CgEChE̕ƃ^Cg`Ȃ; false ȂEChE̕Ă` (l false). ܂, p^ lbound  true  ^CgEChE̕ĕ`ȂƂ p^ lbmsg  true Ȃ ̎|bZ[Wo͂; false Ȃo͂Ȃ (l true). 

=end

      def ypttl(cside, islct, cttl, py, temp=nil)
	@param.sync
	if(temp)
	   @temp_param.set(temp, @param, @backup)
	   @temp_param.sync
	end

	DCL.uypttl(cside, islct, cttl, py)

	if(temp)
	   @backup.sync
	   @temp_param.clear
	end
	nil
      end

# by DCL manual
#english
=begin
---Axis.ypttl(cside, islct, cttl, py, temp=nil)
    Draws a title. 

    Arguments
    * cside (String) : Specifies the position of the axis to draw the title. ('B','T','U')
    * islct (Fixnum) : Specifies the attributes of the title to be drawn.
    * cttl (String) : The title to be drawn.
    * py (Fixnum) : Specifies the position to draw the title with a floating-point value between -1 and +1. Left-aligned when -1, centered when 0, and right-aligned when +1.
    * temp (Hash) : temporary parameters.

    Notes
    (1)UYPTTL is called in this method.
    (2)The character size of the title is specified by the internal variable rsizec(i).
    (3)The angle of rotation of the title text is specified by the internal variable irotc(zs).
    (4)The line index of the line for the characters in the title is specified by the internal variable indexl(i).
    (5)When the internal variable lbound is true and the title exceeds the width of the window, the title is not drawn. When lbound is false, the title is drawn when when it exceeds the window width. (The initial value is false.) Also, when the internal variable lbound is true, the title exceeds the window width so it&nbsp; cannot be drawn, a message will be printed if the internal variable lbmsg is true, and will not be printed when false. (The initial value is true.)

=end
#japanese
=begin
---Axis.ypttl(cside, islct, cttl, py, temp=nil)
    ^Cg`. 

     
    * cside (String) : W`ꏊw肷 ('L','R','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * py (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UYPTTL ĂłB
    (2)^Cg̑̕傫̓p^ rsizec(i) ߂. 
    (3)^Cg̉̕]p̓p^ irotc(zs) ߂. 
    (4)^Cg̕`̃CCfNX̓p^ indexl(i)߂. 
    (5)p^ lbound  true  ^CgEChE̕ƃ^Cg`Ȃ; false ȂEChE̕Ă` (l false). ܂, p^ lbound  true  ^CgEChE̕ĕ`ȂƂ p^ lbmsg  true Ȃ ̎|bZ[Wo͂; false Ȃo͂Ȃ (l true). 

=end

      def xmttl(cside, cttl, px, temp=nil)
	@param.sync
	if(temp)
	   @temp_param.set(temp, @param, @backup)
	   @temp_param.sync
	end

	DCL.uxmttl(cside, cttl, px)

	if(temp)
	   @backup.sync
	   @temp_param.clear
	end
	nil
      end

# by DCL manual
#english
=begin
---Axis.xmttl(cside, cttl, px, temp=nil)
    Draws a major title.

    Arguments
    * cside (String) : Specifies the position to draw the axis. ('B','T','U')(See ((<Specification of Attributes>)).).
    * cttl (String) : The title to draw.
    * px (Fixnum) : Specifies the position to draw the title with a floating-point value between -1 and +1. Left-aligned when -1, centered when 0, and right-aligned when +1.
    * temp (Hash) : temporary parameters

    Notes
    (1)UXMTTL is called in this method.
    (2)This routine uses UXPTTL/UYPTTL (ISLCT=2) to draw the title. 

=end
#japanese
=begin
---Axis.xmttl(cside, cttl, px, temp=nil)
    傫߂̃^Cg`. 

    
    * cside (String) : W`ꏊw肷 ('B','T','U')( ((<̎w@>)) Q).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UXMTTL ĂłB
    (2)̃\bh UXPTTL (ISLCT=2)g ^Cg`Ă.

=end
 
      def ymttl(cside, cttl, py, temp=nil)
	@param.sync
	if(temp)
	   @temp_param.set(temp, @param, @backup)
	   @temp_param.sync
	end

	DCL.uymttl(cside, cttl, py)
	 
	if(temp)
	   @backup.sync
	   @temp_param.clear
	end
	nil
      end

# by DCL manual
#english
=begin
---Axis.ymttl(cside, cttl, py, temp=nil)
    Draws a major title.

    Arguments
    * cside (String) : Specifies the position to draw the axis. ('L','R','U')(See ((<Specification of Attributes>)).).
    * cttl (String) : The title to draw.
    * py (Fixnum) : Specifies the position to draw the title with a floating-point value between -1 and +1. Left-aligned when -1, centered when 0, and right-aligned when +1.
    * temp (Hash) : temporary parameters

    Notes
    (1)UYMTTL is called in this method.
    (2)This routine uses UXPTTL/UYPTTL (ISLCT=2) to draw the title. 

=end
#japanese
=begin
---Axis.ymttl(cside, cttl, py, temp=nil)
    傫߂̃^Cg`. 

    
    * cside (String) : W`ꏊw肷 ('L','R','U')( ((<̎w@>)) Q).
    * islct (Fixnum) : `̑w肷 ( ((<̎w@>)) Q).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UYMTTL ĂłB
    (2)̃\bh UYPTTL (ISLCT=2)g ^Cg`Ă.

=end
      
      def xsttl(cside, cttl, px, temp=nil)
	@param.sync
	if(temp)
	   @temp_param.set(temp, @param, @backup)
	   @temp_param.sync
	end

	DCL.uxsttl(cside, cttl, px)

	if(temp)
	   @backup.sync
	   @temp_param.clear
	end
	nil
      end
 
# by DCL manual
#english
=begin
---Axis.xsttl(cside, cttl, px, temp=nil)
    Draws a minor title. 

    Arguments
    * cside (String) : Specifies the position to draw the axis. ('B','T','U')(See ((<Specification of Attributes>)).).
    * cttl (String) : The title to draw.
    * px (Fixnum) : Specifies the position to draw the title with a floating-point value between -1 and +1. Left-aligned when -1, centered when 0, and right-aligned when +1.
    * temp (Hash) : temporary parameters.

    Notes
    (1)UXSTTL is called in this method.
    (2)This routine uses UXPTTL/UYPTTL (ISLCT=1) to draw the title. 

=end
#japanese
=begin
---Axis.xsttl(cside, cttl, px, temp=nil)
    ߂̃^Cg`. 

    
    * cside (String) : W`ꏊw肷 ('B','T','U')( ((<̎w@>)) Q).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UXSTTL ĂłB
    (2)̃\bh UXPTTL (ISLCT=1)g ^Cg`Ă.

=end
    
      def ysttl(cside, cttl, py, temp=nil)
	@param.sync
	if(temp)
	   @temp_param.set(temp, @param, @backup)
	   @temp_param.sync
	end

	DCL.uysttl(cside, cttl, py)
	if(temp)
	   @backup.sync
	   @temp_param.clear
	end
	nil
      end

# by DCL manual
#english
=begin
---Axis.ysttl(cside, cttl, yx, temp=nil)
    Draws a minor title. 

    Arguments
    * cside (String) : Specifies the position to draw the axis. ('L','R','U')(See ((<Specification of Attributes>)).).
    * cttl (String) : The title to draw.
    * py (Fixnum) : Specifies the position to draw the title with a floating-point value between -1 and +1. Left-aligned when -1, centered when 0, and right-aligned when +1.
    * temp (Hash) : temporary parameters.

    Notes
    (1)UYSTTL is called in this method.
    (2)This routine uses UXPTTL/UYPTTL (ISLCT=1) to draw the title. 

=end
#japanese
=begin
---Axis.ysttl(cside, cttl, py, temp=nil)
    ߂̃^Cg`. 

    
    * cside (String) : W`ꏊw肷 ('L','R','U')( ((<̎w@>)) Q).
    * islct (Fixnum) : `̑w肷 ( ((<̎w@>)) Q).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UYSTTL ĂłB
    (2)̃\bh UYPTTL (ISLCT=1)g ^Cg`Ă.

=end

      def draw(x=nil, y=nil, temp=nil)
	rundef = Common.rundef
	if(x.is_a?(Hash))
	  temp = x
	elsif((x.is_a?(NArray))&&(x.rank==2))
	  y = x.shape[1].to_f
	  x = x.shape[0].to_f
	  Basics.checkundef(x, y)
	elsif(Basics.typearray(x) && Basics.typearray(y))
	  Basics.checkundef(x, y)
	elsif(x==rundef || y==rundef)
	  Basics.checkundef(x, y)
	elsif(x==nil&&y==nil)
	  Basics.checkundef(1.0, 1.0)
	end
	@param.sync
	if(temp)
	   @temp_param.set(temp, @param, @backup)
	   @temp_param.sync
	end

	Fig.settrf
    
	DCL.usdaxs

	if(temp)
	   @backup.sync
	   @temp_param.clear
	end
	nil
      end

# by DCL manual
#english
=begin
---Axis.draw(x=nil, y=nil, temp=nil)
    Plots the default coordinate axis. Also draws the title when it is specified.

    Arguments
    * x: Array of X axis (Array or NArray)
    * y: Array of Y axis (Array or NArray)
    * temp: temporary parameters(Hash)

    Notes
    (1)USDAXS is called in this method.
    (2)If window is not set, window is automatically set by arguments x,y.

=end
#japanese
=begin
---Axis.draw(x=nil, y=nil, temp=nil)
    ftHg̍W`. ^Cgw肳Ă΃^Cg. 

    
    * x: X̍W\z (Array or NArray)
    * y: Y̍W\z (Array or NArray)
    * temp: e|p^(Hash)

    l
    (1)̃\bhUSDAXSĂłB
    (2)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end

      def xax(cside, x=nil, y=nil, temp=nil)
	if(x.is_a?(Hash))
	  temp = x
	elsif((x.is_a?(NArray))&&(x.rank==2))
	  y = x.shape[1].to_f
	  x = x.shape[0].to_f
	  Basics.checkundef(x, y)
	elsif(Basics.typearray(x) && Basics.typearray(y))
	  Basics.checkundef(x, y)
	elsif(x==nil&&y==nil)
	  Basics.checkundef(1.0, 1.0)
	end
	@param.sync
	if(temp)
	   @temp_param.set(temp, @param, @backup)
	   @temp_param.sync
	end
	Fig.settrf
	
	DCL.usxaxs(cside)
	
	if(temp)
	   @backup.sync
	   @temp_param.clear
	end
	nil
      end

# by DCL manual
#english
=begin
---Axis.xax(cside, x=nil, y=nil, temp=nil)
    Calculates appropriate intervals for the tick marks and labels for the currently set transformation function, and plots a single coordinate axis in the specified position. 

    Arguments
    * cside: The position of the coordinate axis ( 'B'/'T'/'U')(String)
    * x: Array of X axis (Array or NArray)
    * y: Array of Y axis (Array or NArray)
    * temp: temporary parameters (Hash)

    Notes
    (1)USXAXS is called in this method.
    (2)If window is not set, window is automatically set by arguments x,y.

=end
#japanese
=begin
---Axis.xax(cside, x=nil, y=nil, temp=nil)
    ݐݒ肳Ă鐳Kϊɑ΂ KȖڐƃxԊuvZ, w肳ꂽꏊɍW{`.

    
    * cside: Ẅʒu ( 'B'/'T'/'U')(String)
    * x: X̍W\z (Array or NArray)
    * y: Y̍W\z (Array or NArray)
    * temp: e|p^(Hash)

    l
    (1)̃\bhUSXAXSĂłB
    (2)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end
  
      def yax(cside, x=nil, y=nil, temp=nil)
	if(x.is_a?(Hash))
	  temp = x
	elsif((x.is_a?(NArray))&&(x.rank==2))
	  y = x.shape[1].to_f
	  x = x.shape[0].to_f
	  Basics.checkundef(x, y)
	elsif(Basics.typearray(x) && Basics.typearray(y))
	  Basics.checkundef(x, y)
	elsif(x==nil&&y==nil)
	  Basics.checkundef(1.0, 1.0)
	end
	@param.sync
	if(temp)
	   @temp_param.set(temp, @param, @backup)
	   @temp_param.sync
	end
	Fig.settrf
	
	DCL.usyaxs(cside)
	if(temp)
	   @backup.sync
	   @temp_param.clear
	end
	nil
      end

# by DCL manual
#english
=begin
---Axis.yax(cside, x=nil, y=nil, temp=nil)
    Calculates appropriate intervals for the tick marks and labels for the currently set transformation function, and plots a single coordinate axis in the specified position. 

    Arguments
    * cside: The position of the coordinate axis ( 'L'/'R'/'U')(String)
    * x: Array of X axis (Array or NArray)
    * y: Array of Y axis (Array or NArray)
    * temp: temporary parameters (Hash)

    Notes
    (1)USYAXS is called in this method.
    (2)If window is not set, window is automatically set by arguments x,y.

=end
#japanese
=begin
---Axis.yax(cside, x=nil, y=nil, temp=nil)
    ݐݒ肳Ă鐳Kϊɑ΂ KȖڐƃxԊuvZ, w肳ꂽꏊɍW{`.

    
    * cside: Ẅʒu ( 'L'/'R'/'U')(String)
    * x: X̍W\z (Array or NArray)
    * y: Y̍W\z (Array or NArray)
    * temp: e|p^(Hash)

    l
    (1)̃\bhUSYAXSĂłB
    (2)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end
  
      module_function :param_init
      module_function :param
      module_function :zfact
      module_function :xpttl
      module_function :ypttl
      module_function :xmttl
      module_function :ymttl
      module_function :xsttl
      module_function :ysttl
      module_function :draw
      module_function :help_params
      module_function :set
      module_function :get
      module_function :sync
      module_function :reset
      module_function :title
      module_function :xax
      module_function :yax
      
      param_init

      @param.keys.each{|i|
	eval "def #{i}; @param['#{i}']; end"
	eval "def #{i}=(val); set('#{i}', val); end"
      }
      
      @param.keys.each{|i|
	eval "module_function :#{i}"
	eval "module_function :#{i}="
      }
    end
  end
end

require "numru/advanceddcl/log"
require "numru/advanceddcl/lin"
